@@ -14,7 +14,24 @@ def lookupFreq(word):
 #    qs = Spelling.objects.filter(Label=word).order_by('-Word__Frequency')
 #    return [q.StressPattern for q in qs]
 
+def categorize_words(words):
+    qs = Lemma.objects.filter(wordform__orthographies__spelling__in = words).distinct().order_by('frequency')
+    t = []
+    for x in words:
+        if x == 'a':
+            t.append((x,'art'))
+        elif x == 'i':
+            t.append((x,'pron'))
+        else:
+            t.append((x,(['NA']+[str(y.category).lower() for y in qs if x in y.get_spelling_set()])[-1]))
+            if t[-1][1] == 'adv':
+                t[-1][1] = 'r'
+    return ['#'.join(x) for x in t if x[1]]
+
+
 def lookupCat(word):
+    if word in ['a','i']:
+        return u'pron'
     qs = Lemma.objects.filter(wordform__orthographies__spelling = word).distinct().order_by('-frequency')
     if len(qs) == 0:
         return 'NA'
